=============================
Node and Edge data interfaces
=============================

.. autopydantic_model:: gridai.interfaces.DistNodeAttrs
    :members:

.. autopydantic_model:: gridai.interfaces.DistEdgeAttrs
    :members:
